==> CGSocialApp-1.1.10.tar.gz: CGSocialApp/action.admin_settings.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGSocialApp (c) 2012 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;
if( !$this->CheckPermission('Modify Site Preferences') ) return;

echo '<div class="pageoverflow" style="text-align: right; width: 80%;">'.
$this->CreateImageLink($id,'defaultadmin',$returnid,
		       $this->Lang('lbl_back'),'icons/system/back.gif',array(),'','',false).'</div><br/>';

echo $this->StartTabHeaders();
echo $this->SetTabHeader('locationsettings',$this->Lang('tab_locationsettings'));
echo $this->SetTabHeader('leaderboardsettings',$this->Lang('tab_leaderboardsettings'));
echo $this->SetTabHeader('usersettings',$this->Lang('tab_usersettings'));
echo $this->SetTabHeader('generalsettings',$this->Lang('tab_generalsettings'));
echo $this->EndTabHeaders();

echo $this->StartTabContent();
echo $this->StartTab('locationsettings',$params);
include(dirname(__FILE__).'/function.admin_locationsettings_tab.php');
echo $this->EndTab();

echo $this->StartTab('leaderboardsettings',$params);
include(dirname(__FILE__).'/function.admin_leaderboardsettings_tab.php');
echo $this->EndTab();

echo $this->StartTab('usersettings',$params);
include(dirname(__FILE__).'/function.admin_usersettings_tab.php');
echo $this->EndTab();

echo $this->StartTab('generalsettings',$params);
include(dirname(__FILE__).'/function.admin_settings_tab.php');
echo $this->EndTab();
echo $this->EndTabContent();

#
# EOF
#
?>

==> CGSocialApp-1.3.1.tar.gz: CGSocialApp/action.admin_settings.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGSocialApp (c) 2013 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;
if( !$this->CheckPermission('Modify Site Preferences') ) return;

echo '<div class="pageoverflow" style="text-align: right; width: 80%;">'.
$this->CreateImageLink($id,'defaultadmin',$returnid,
		       $this->Lang('lbl_back'),'icons/system/back.gif',array(),'','',false).'</div><br/>';

echo $this->StartTabHeaders();
echo $this->SetTabHeader('locationsettings',$this->Lang('tab_locationsettings'));
echo $this->SetTabHeader('usersettings',$this->Lang('tab_usersettings'));
echo $this->SetTabHeader('friendsettings',$this->Lang('tab_friendsettings'));
echo $this->SetTabHeader('checkinsettings',$this->Lang('tab_checkinsettings'));
echo $this->SetTabHeader('leaderboardsettings',$this->Lang('tab_leaderboardsettings'));
echo $this->SetTabHeader('generalsettings',$this->Lang('tab_generalsettings'));
echo $this->EndTabHeaders();

echo $this->StartTabContent();
echo $this->StartTab('locationsettings',$params);
include(__DIR__.'/function.admin_locationsettings_tab.php');
echo $this->EndTab();

echo $this->StartTab('usersettings',$params);
include(__DIR__.'/function.admin_usersettings_tab.php');
echo $this->EndTab();

echo $this->StartTab('friendsettings',$params);
include(__DIR__.'/function.admin_friendsettings_tab.php');
echo $this->EndTab();

echo $this->StartTab('checkinsettings',$params);
include(__DIR__.'/function.admin_checkinsettings_tab.php');
echo $this->EndTab();

echo $this->StartTab('leaderboardsettings',$params);
include(__DIR__.'/function.admin_leaderboardsettings_tab.php');
echo $this->EndTab();

echo $this->StartTab('generalsettings',$params);
include(__DIR__.'/function.admin_settings_tab.php');
echo $this->EndTab();
echo $this->EndTabContent();

#
# EOF
#
?>
